@@ -4,6 +4,10 @@ test_that("describe_jobs", {
   expect_error(svc$describe_jobs(), NA)
 })
 
+test_that("describe_launch_configuration_templates", {
+  expect_error(svc$describe_launch_configuration_templates(), NA)
+})
+
 test_that("describe_recovery_instances", {
   expect_error(svc$describe_recovery_instances(), NA)
 })
@@ -12,6 +16,10 @@ test_that("describe_replication_configuration_templates", {
   expect_error(svc$describe_replication_configuration_templates(), NA)
 })
 
+test_that("describe_source_networks", {
+  expect_error(svc$describe_source_networks(), NA)
+})
+
 test_that("describe_source_servers", {
   expect_error(svc$describe_source_servers(), NA)
 })
